@@ -6,8 +6,11 @@ from numba_stats import norm, uniform # faster replacements for scipy.stats func
 import numpy as np
 from scipy.integrate import quad
 
-from termcolor import colored
+# from termcolor import colored
+from console import fg, fx
 
+import json
+import datetime as dt
 
 #-----------------------------------------------
 def gauss(x, area,channel,sigma):
@@ -29,10 +32,15 @@ def print_errors(m2, chi2dof):
         val = m2.values[key]
         if val<0:val=-val
 
+        if val==0:
+            errval = 0
+        else:
+            errval = 100*err/val
+
         if chi2dof>1:
             err = err * np.sqrt(chi2dof)
 
-        print(f"| {key:7} | {val:11.2f} | {err:9.2f}  |  {100*err/val:6.1f}% |", end="")
+        print(f"| {key:7} | {val:11.2f} | {err:9.2f}  |  {errval:6.1f}% |", end="")
         if key=="area":
             print(f" {100/np.sqrt(val):5.2f}%  (sqrt)|")
         elif key=="fwhm":
@@ -100,7 +108,7 @@ def main(x,y,dy, polorder = None):
                 fwhm = 5,
                 a=1, b=1  )
 
-    print_errors(m2, 0) # my nice table at end
+    print_errors(m2, 0) # my nice table BEFORE
 
     # m2.limits["a", "b", "c"] = (0, None)
 
@@ -123,6 +131,9 @@ def main(x,y,dy, polorder = None):
                      m2.values['fwhm']
     )
 
+    #-------------------- this part serves to provide y(x) points
+    #                     for various scenarios to PLOT IT later
+    #                     not much used..... i think
     def sig(x):
         return model_chi2(x, 0,
                           0,
@@ -197,18 +208,29 @@ def main(x,y,dy, polorder = None):
     print(f" ... and all ok   ... {NOError}")
 
 
+    ok = True
     if not(m2.valid):
-        print( colored('X... ____________FIT SEEMS NOT  VALID___________', 'red') )
-    elif  not(m2.accurate):
-        print( colored('X... ____________VALID BUT NOT ACCURATE___________', 'yellow') )
-    else:
-        print( colored('i...    fit seems OK to me', 'green') )
+        print( f"{fg.red}X... ____________FIT SEEMS NOT  VALID___________{fg.default}" )
+        ok = False
+    if  not(m2.accurate):
+        print( f"{fg.yellow}X... ____________          NOT ACCURATE_________{fg.default}" )
+    if not NOError:
+        print( f"{fg.red}X... ____________SOME ERROR IN FIT     _________{fg.default}")
+        ok = False
+    if m2.values['area'] + sigarea[0]<=0:
+        print( f"{fg.red}X... ____________empirically : error   _________{fg.default}")
+        ok = False
+    if ok:
+        print( f"{fg.green}i...    fit seems OK to me {fg.default}" )
 
 
     print("_________________________________________________")
 
     # ----- super return"
     res = {}
+
+    res['ok'] = ok
+
     res['yf'] = yf
     res['yf_l'] = yf_l
     res['yf_h'] = yf_h
@@ -251,8 +273,21 @@ def main(x,y,dy, polorder = None):
     res['dfwhm']   = err
 
 
+    # empirical eerror
+    if m2.values['area'] + sigarea[0]>0:
+        res['diff_fit_int_proc'] = 100*abs(m2.values['area'] - sigarea[0])/(m2.values['area'] + sigarea[0])/2
+    else:
+        res['diff_fit_int_proc'] = 0
 
-    res['diff_fit_int_proc'] = 100*abs(m2.values['area'] - sigarea[0])/(m2.values['area'] + sigarea[0])/2
+    # --------dump-----without np arrays
+    dum = {}
+    dum['timemark'] = dt.datetime.now().strftime("%Y/%m/%d %H:%M:%S")
+    for i in res.keys():
+        if not (type(res[i]) == np.ndarray):
+            dum[i] = res[i]
+    with open(".gpol1.results", "a") as f:
+        json.dump( dum , f , indent=4 )
+        f.write("\n")
 
     return res
     # return (yf,yf_l,yf_h)
