@@ -7,7 +7,8 @@ import iminuit
 from numba_stats import norm, uniform # faster replacements for scipy.stats functions
 import numpy as np
 
-from termcolor import colored
+#from termcolor import colored
+from console import fg,fx
 import re
 
 
@@ -54,7 +55,7 @@ import re
 
 
 def main(x,y,dy, polorder = None):
-    print("__________________________________________________")
+    print("__________________________________________________ chebypol")
 
     global bin1 # trick for better convergence
     bin1 = x[0]
@@ -215,11 +216,11 @@ def main(x,y,dy, polorder = None):
 
 
     if not(m2.valid):
-        print( colored('X... ____________FIT SEEMS NOT  VALID___________', 'red') )
+        print( f"{fg.red}X... ____________FIT SEEMS NOT  VALID___________ {fg.default}" )
     elif  not(m2.accurate):
-        print( colored('X... ____________VALID BUT NOT ACCURATE___________', 'yellow') )
+        print( f"{fg.yellow}X... ____________VALID BUT NOT ACCURATE___________ {fg.default}" )
     else:
-        print( colored('i...    fit seems OK to me', 'green') )
+        print( f"{fg.green}i...    fit seems OK to me {fg.default}" )
 
 
 
