@@ -32,6 +32,7 @@ def main( *args ):
     """
     I want to zoom:  object(histo) xlow,xhigh
     """
+    display = False # NO DISPLAY HERE
     if len(args)<1:
         print("X... no object name given  (and no model given too)")
         return
@@ -145,7 +146,9 @@ def main( *args ):
 
     # ///////////////////////////////////////////////////// plotting results
 
-    cmain = ROOT.gPad.GetCanvas()  # reset all canvas
+    #cmain = ROOT.gPad.GetCanvas()  # reset all canvas
+    #cmain.Clear()
+    cmain = ROOT.gPad  # reset JUST THE PAD
     cmain.Clear()
     #cmain.Divide(1,1) # div canvas
     #cmain.cd(1)
@@ -167,10 +170,11 @@ def main( *args ):
     # zoom works on energies!
     # g_orig.GetXaxis().SetRangeUser( (x12[0] - calb)/cala, (x12[1] - calb)/cala )
 
-    g_orig.SetMarkerStyle(7) # small circle , no lines...
-    g_orig.Draw() # for histo NOT PAWL;  it works with NO PAWL TGraph too
-    ROOT.gPad.Modified()
-    ROOT.gPad.Update()
+    if display:
+        g_orig.SetMarkerStyle(7) # small circle , no lines...
+        g_orig.Draw() # for histo NOT PAWL;  it works with NO PAWL TGraph too
+        ROOT.gPad.Modified()
+        ROOT.gPad.Update()
 
 
 
