@@ -19,11 +19,15 @@ def register(obj, NAME ):
     """
     #NAME = "fit"
     obj.SetName(NAME)
+
     # obj.SetTitle(NAME)
     oldg = ROOT.gROOT.GetListOfSpecials().FindObject(NAME)
     if oldg:
+        print(f"i...    removing existing object {NAME}")
         ROOT.gROOT.GetListOfSpecials().Remove(oldg)
     ROOT.gROOT.GetListOfSpecials().Add(obj)
+    #print(f"i... object NAME={NAME} registered")
+    #ROOT.gROOT.GetListOfSpecials().ls()
     return
 
 
@@ -77,7 +81,7 @@ def listpy():
     #print("REPO:",tgt2) # I forgot to link inside the repo
     #print("REPO",files)
     corenames = [ os.path.splitext(x)[0].split("pr_")[1] for x in files]
-    print(f"i... modules available in REPO:\n          {corenames}")
+    #print(f"i... modules available in REPO:\n          {corenames}")
     files = [ tgt2+"/"+x for x in files ]
     #- GO back from repo
     os.chdir( dirnow )
@@ -91,7 +95,7 @@ def listpy():
         #files = filescur
     else:
         corenames = [ os.path.splitext(x)[0].split("pr_")[1] for x in filescur]
-        print(f"i... modules available in CURR:\n          {corenames}")
+        #print(f"i... modules available in CURR:\n          {corenames}")
         # files = [x for x in files if x.find("pr_model_")!=0] # models- I exclude?
         files =  files + filescur
 
